@@ -16,27 +16,9 @@ class VertexPaintDirt(bpy_types.Operator):
     bl_rna = None
     ''' '''
 
-    blur_iterations = None
-    ''' '''
-
-    blur_strength = None
-    ''' '''
-
-    clean_angle = None
-    ''' '''
-
-    dirt_angle = None
-    ''' '''
-
-    dirt_only = None
-    ''' '''
-
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -49,6 +31,18 @@ class VertexPaintDirt(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -79,6 +73,12 @@ class VertexPaintDirt(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -133,6 +133,18 @@ class VertexPaintDirt(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -159,3 +171,11 @@ def applyVertexDirt(me, blur_iterations, blur_strength, clamp_dirt,
     '''
 
     pass
+
+
+def get_vcolor_layer_data(me):
+    ''' 
+
+    '''
+
+    pass
