@@ -3,7 +3,7 @@ import typing
 
 
 def context_menu():
-    '''Display properties editor context_menu 
+    ''' Display properties editor context_menu
 
     '''
 
@@ -31,49 +31,49 @@ def directory_browse(directory: str = "",
                      relative_path: bool = True,
                      display_type: typing.Union[str, int] = 'DEFAULT',
                      sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
-    '''Open a directory browser, Hold Shift to open the file, Alt to browse containing directory 
+    ''' Open a directory browser, Hold Shift to open the file, Alt to browse containing directory
 
-    :param directory: Directory, Directory of the file 
+    :param directory: Directory, Directory of the file
     :type directory: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param relative_path: Relative Path, Select the file relative to the blend file 
+    :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
     '''
 
@@ -101,49 +101,49 @@ def file_browse(filepath: str = "",
                 relative_path: bool = True,
                 display_type: typing.Union[str, int] = 'DEFAULT',
                 sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
-    '''Open a file browser, Hold Shift to open the file, Alt to browse containing directory 
+    ''' Open a file browser, Hold Shift to open the file, Alt to browse containing directory
 
-    :param filepath: File Path, Path to file 
+    :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param relative_path: Relative Path, Select the file relative to the blend file 
+    :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
     '''
 
