@@ -19,17 +19,18 @@ def active_frames_delete_all():
     pass
 
 
-def annotate(
-        mode: typing.Union[str, int] = 'DRAW',
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def annotate(mode: typing.Union[str, int] = 'DRAW',
+             stroke: typing.
+             Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+                   List['bpy.types.OperatorStrokeElement'],
+                   'bpy_prop_collection'] = None,
+             wait_for_input: bool = True):
     ''' Make annotations on the active data
 
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Annotation strokes.
     :type mode: typing.Union[str, int]
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     '''
@@ -218,8 +219,10 @@ def dissolve(type: typing.Union[str, int] = 'POINTS'):
 
 
 def draw(mode: typing.Union[str, int] = 'DRAW',
-         stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                              'bpy_prop_collection'] = None,
+         stroke: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+               List['bpy.types.OperatorStrokeElement'],
+               'bpy_prop_collection'] = None,
          wait_for_input: bool = True,
          disable_straight: bool = False,
          disable_fill: bool = False,
@@ -229,7 +232,7 @@ def draw(mode: typing.Union[str, int] = 'DRAW',
     :param mode: Mode, Way to interpret mouse movements * DRAW Draw Freehand, Draw freehand stroke(s). * DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s). * DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected). * ERASER Eraser, Erase Grease Pencil strokes.
     :type mode: typing.Union[str, int]
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately
     :type wait_for_input: bool
     :param disable_straight: No Straight lines, Disable key for straight lines
@@ -579,14 +582,14 @@ def reveal(select: bool = True):
     pass
 
 
-def sculpt_paint(
-        stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
-                             'bpy_prop_collection'] = None,
-        wait_for_input: bool = True):
+def sculpt_paint(stroke: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.
+        List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection'] = None,
+                 wait_for_input: bool = True):
     ''' Apply tweaks to strokes by painting over the strokes
 
     :param stroke: Stroke
-    :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
+    :type stroke: typing.Union[typing.Dict[str, 'bpy.types.OperatorStrokeElement'], typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
     :param wait_for_input: Wait for Input, Enter a mini 'sculpt-mode' if enabled, otherwise, exit after drawing a single stroke
     :type wait_for_input: bool
     '''
@@ -719,14 +722,16 @@ def select_grouped(type: typing.Union[str, int] = 'LAYER'):
 
 
 def select_lasso(mode: typing.Union[str, int] = 'SET',
-                 path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None):
+                 path: typing.
+                 Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+                       List['bpy.types.OperatorMousePath'],
+                       'bpy_prop_collection'] = None):
     ''' Select Grease Pencil strokes using lasso selection
 
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection. * XOR Difference, Inverts existing selection. * AND Intersect, Intersect existing selection.
     :type mode: typing.Union[str, int]
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     '''
 
     pass
@@ -858,13 +863,13 @@ def stroke_change_color(material: str = ""):
     pass
 
 
-def stroke_cutter(
-        path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                           'bpy_prop_collection'] = None):
+def stroke_cutter(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None):
     ''' Select section and cut
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     '''
 
     pass
