@@ -6,8 +6,10 @@ import bpy.types
 def fbx(filepath: str = "",
         directory: str = "",
         filter_glob: str = "*.fbx",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         ui_tab: typing.Union[str, int] = 'MAIN',
         use_manual_orientation: bool = False,
         global_scale: float = 1.0,
@@ -38,7 +40,7 @@ def fbx(filepath: str = "",
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param ui_tab: ui_tab, Import options categories * MAIN Main, Main basic settings. * ARMATURE Armatures, Armature-related settings.
     :type ui_tab: typing.Union[str, int]
     :param use_manual_orientation: Manual Orientation, Specify orientation and scale, instead of using embedded data in FBX file
@@ -88,8 +90,10 @@ def fbx(filepath: str = "",
 
 def gltf(filepath: str = "",
          filter_glob: str = "*.glb;*.gltf",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          loglevel: int = 0,
          import_pack_images: bool = True,
          import_shading: typing.Union[str, int] = 'NORMALS'):
@@ -100,7 +104,7 @@ def gltf(filepath: str = "",
     :param filter_glob: filter_glob
     :type filter_glob: str
     :param files: File Path
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param loglevel: Log Level, Log Level
     :type loglevel: int
     :param import_pack_images: Pack images, Pack all images into .blend file
