@@ -7,8 +7,10 @@ import bpy.types
 def add_and_link_node(
         type: str = "",
         use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None,
+        settings: typing.
+        Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+              List['bl_operators.node.NodeSetting'],
+              'bpy_prop_collection'] = None,
         link_socket_index: int = 0):
     ''' Add a node to the active tree and link to an existing socket
 
@@ -17,7 +19,7 @@ def add_and_link_node(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     :param link_socket_index: Link Socket Index, Index of the socket to link
     :type link_socket_index: int
     '''
@@ -114,11 +116,12 @@ def add_mask(name: str = "Mask"):
     pass
 
 
-def add_node(
-        type: str = "",
-        use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None):
+def add_node(type: str = "",
+             use_transform: bool = False,
+             settings: typing.
+             Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+                   List['bl_operators.node.NodeSetting'],
+                   'bpy_prop_collection'] = None):
     ''' Add a node to the active tree
 
     :param type: Node Type, Node type
@@ -126,19 +129,20 @@ def add_node(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     '''
 
     pass
 
 
-def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                   'bpy_prop_collection'] = None,
+def add_reroute(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                 cursor: int = 8):
     ''' Add a reroute node
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -146,12 +150,13 @@ def add_reroute(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
     pass
 
 
-def add_search(
-        type: str = "",
-        use_transform: bool = False,
-        settings: typing.Union[typing.List['bl_operators.node.NodeSetting'],
-                               'bpy_prop_collection'] = None,
-        node_item: typing.Union[str, int] = ''):
+def add_search(type: str = "",
+               use_transform: bool = False,
+               settings: typing.
+               Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.
+                     List['bl_operators.node.NodeSetting'],
+                     'bpy_prop_collection'] = None,
+               node_item: typing.Union[str, int] = ''):
     ''' Add a node to the active tree
 
     :param type: Node Type, Node type
@@ -159,7 +164,7 @@ def add_search(
     :param use_transform: Use Transform, Start transform operator after inserting the node
     :type use_transform: bool
     :param settings: Settings, Settings to be applied on the newly created node
-    :type settings: typing.Union[typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
+    :type settings: typing.Union[typing.Dict[str, 'bl_operators.node.NodeSetting'], typing.List['bl_operators.node.NodeSetting'], 'bpy_prop_collection']
     :param node_item: Node Type, Node type
     :type node_item: typing.Union[str, int]
     '''
@@ -439,13 +444,14 @@ def link_viewer():
     pass
 
 
-def links_cut(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                 'bpy_prop_collection'] = None,
+def links_cut(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
               cursor: int = 12):
     ''' Use the mouse to cut (remove) some links
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param cursor: Cursor
     :type cursor: int
     '''
@@ -703,16 +709,18 @@ def select_grouped(extend: bool = False,
     pass
 
 
-def select_lasso(tweak: bool = False,
-                 path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
-                 mode: typing.Union[str, int] = 'SET'):
+def select_lasso(
+        tweak: bool = False,
+        path: typing.Union[
+            typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+            List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
+        mode: typing.Union[str, int] = 'SET'):
     ''' Select nodes using lasso selection
 
     :param tweak: Tweak, Only activate when mouse is not over a node - useful for tweak gesture
     :type tweak: bool
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
     :type mode: typing.Union[str, int]
     '''
