@@ -3,7 +3,7 @@ import typing
 
 
 def autocomplete():
-    '''Show a list of used text in the open document 
+    ''' Show a list of used text in the open document
 
     '''
 
@@ -11,9 +11,9 @@ def autocomplete():
 
 
 def comment_toggle(type: typing.Union[str, int] = 'TOGGLE'):
-    '''Undocumented contribute <https://developer.blender.org/T51061> 
+    ''' Undocumented contribute <https://developer.blender.org/T51061>
 
-    :param type: Type, Add or remove comments 
+    :param type: Type, Add or remove comments
     :type type: typing.Union[str, int]
     '''
 
@@ -21,9 +21,9 @@ def comment_toggle(type: typing.Union[str, int] = 'TOGGLE'):
 
 
 def convert_whitespace(type: typing.Union[str, int] = 'SPACES'):
-    '''Convert whitespaces by type 
+    ''' Convert whitespaces by type
 
-    :param type: Type, Type of whitespace to convert to 
+    :param type: Type, Type of whitespace to convert to
     :type type: typing.Union[str, int]
     '''
 
@@ -31,7 +31,7 @@ def convert_whitespace(type: typing.Union[str, int] = 'SPACES'):
 
 
 def copy():
-    '''Copy selected text to clipboard 
+    ''' Copy selected text to clipboard
 
     '''
 
@@ -39,11 +39,11 @@ def copy():
 
 
 def cursor_set(x: int = 0, y: int = 0):
-    '''Set cursor position 
+    ''' Set cursor position
 
-    :param x: X 
+    :param x: X
     :type x: int
-    :param y: Y 
+    :param y: Y
     :type y: int
     '''
 
@@ -51,7 +51,7 @@ def cursor_set(x: int = 0, y: int = 0):
 
 
 def cut():
-    '''Cut selected text to clipboard 
+    ''' Cut selected text to clipboard
 
     '''
 
@@ -59,9 +59,9 @@ def cut():
 
 
 def delete(type: typing.Union[str, int] = 'NEXT_CHARACTER'):
-    '''Delete text by cursor position 
+    ''' Delete text by cursor position
 
-    :param type: Type, Which part of the text to delete 
+    :param type: Type, Which part of the text to delete
     :type type: typing.Union[str, int]
     '''
 
@@ -69,7 +69,7 @@ def delete(type: typing.Union[str, int] = 'NEXT_CHARACTER'):
 
 
 def duplicate_line():
-    '''Duplicate the current line 
+    ''' Duplicate the current line
 
     '''
 
@@ -77,7 +77,7 @@ def duplicate_line():
 
 
 def find():
-    '''Find specified text 
+    ''' Find specified text
 
     '''
 
@@ -85,7 +85,7 @@ def find():
 
 
 def find_set_selected():
-    '''Find specified text and set as selected 
+    ''' Find specified text and set as selected
 
     '''
 
@@ -93,7 +93,7 @@ def find_set_selected():
 
 
 def indent():
-    '''Indent selected text 
+    ''' Indent selected text
 
     '''
 
@@ -101,7 +101,7 @@ def indent():
 
 
 def indent_or_autocomplete():
-    '''Indent selected text or autocomplete 
+    ''' Indent selected text or autocomplete
 
     '''
 
@@ -109,9 +109,9 @@ def indent_or_autocomplete():
 
 
 def insert(text: str = ""):
-    '''Insert text at cursor position 
+    ''' Insert text at cursor position
 
-    :param text: Text, Text to insert at the cursor position 
+    :param text: Text, Text to insert at the cursor position
     :type text: str
     '''
 
@@ -119,9 +119,9 @@ def insert(text: str = ""):
 
 
 def jump(line: int = 1):
-    '''Jump cursor to line 
+    ''' Jump cursor to line
 
-    :param line: Line, Line number to jump to 
+    :param line: Line, Line number to jump to
     :type line: int
     '''
 
@@ -129,7 +129,7 @@ def jump(line: int = 1):
 
 
 def line_break():
-    '''Insert line break at cursor position 
+    ''' Insert line break at cursor position
 
     '''
 
@@ -137,7 +137,7 @@ def line_break():
 
 
 def line_number():
-    '''The current line number 
+    ''' The current line number
 
     '''
 
@@ -145,7 +145,7 @@ def line_number():
 
 
 def make_internal():
-    '''Make active text file internal 
+    ''' Make active text file internal
 
     '''
 
@@ -153,9 +153,9 @@ def make_internal():
 
 
 def move(type: typing.Union[str, int] = 'LINE_BEGIN'):
-    '''Move cursor to position type 
+    ''' Move cursor to position type
 
-    :param type: Type, Where to move cursor to 
+    :param type: Type, Where to move cursor to
     :type type: typing.Union[str, int]
     '''
 
@@ -163,9 +163,9 @@ def move(type: typing.Union[str, int] = 'LINE_BEGIN'):
 
 
 def move_lines(direction: typing.Union[str, int] = 'DOWN'):
-    '''Move the currently selected line(s) up/down 
+    ''' Move the currently selected line(s) up/down
 
-    :param direction: Direction 
+    :param direction: Direction
     :type direction: typing.Union[str, int]
     '''
 
@@ -173,9 +173,9 @@ def move_lines(direction: typing.Union[str, int] = 'DOWN'):
 
 
 def move_select(type: typing.Union[str, int] = 'LINE_BEGIN'):
-    '''Move the cursor while selecting 
+    ''' Move the cursor while selecting
 
-    :param type: Type, Where to move cursor to, to make a selection 
+    :param type: Type, Where to move cursor to, to make a selection
     :type type: typing.Union[str, int]
     '''
 
@@ -183,7 +183,7 @@ def move_select(type: typing.Union[str, int] = 'LINE_BEGIN'):
 
 
 def new():
-    '''Create a new text data-block 
+    ''' Create a new text data-block
 
     '''
 
@@ -211,49 +211,49 @@ def open(filepath: str = "",
          display_type: typing.Union[str, int] = 'DEFAULT',
          sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
          internal: bool = False):
-    '''Open a new text data-block 
+    ''' Open a new text data-block
 
-    :param filepath: File Path, Path to file 
+    :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
-    :param internal: Make internal, Make text file internal after loading 
+    :param internal: Make internal, Make text file internal after loading
     :type internal: bool
     '''
 
@@ -261,7 +261,7 @@ def open(filepath: str = "",
 
 
 def overwrite_toggle():
-    '''Toggle overwrite while typing 
+    ''' Toggle overwrite while typing
 
     '''
 
@@ -269,9 +269,9 @@ def overwrite_toggle():
 
 
 def paste(selection: bool = False):
-    '''Paste text from clipboard 
+    ''' Paste text from clipboard
 
-    :param selection: Selection, Paste text selected elsewhere rather than copied (X11 only) 
+    :param selection: Selection, Paste text selected elsewhere rather than copied (X11 only)
     :type selection: bool
     '''
 
@@ -279,7 +279,7 @@ def paste(selection: bool = False):
 
 
 def refresh_pyconstraints():
-    '''Refresh all pyconstraints 
+    ''' Refresh all pyconstraints
 
     '''
 
@@ -287,7 +287,7 @@ def refresh_pyconstraints():
 
 
 def reload():
-    '''Reload active text data-block from its file 
+    ''' Reload active text data-block from its file
 
     '''
 
@@ -295,7 +295,7 @@ def reload():
 
 
 def replace():
-    '''Replace text with the specified text 
+    ''' Replace text with the specified text
 
     '''
 
@@ -303,7 +303,7 @@ def replace():
 
 
 def replace_set_selected():
-    '''Replace text with specified text and set as selected 
+    ''' Replace text with specified text and set as selected
 
     '''
 
@@ -311,9 +311,9 @@ def replace_set_selected():
 
 
 def resolve_conflict(resolution: typing.Union[str, int] = 'IGNORE'):
-    '''When external text is out of sync, resolve the conflict 
+    ''' When external text is out of sync, resolve the conflict
 
-    :param resolution: Resolution, How to solve conflict due to differences in internal and external text 
+    :param resolution: Resolution, How to solve conflict due to differences in internal and external text
     :type resolution: typing.Union[str, int]
     '''
 
@@ -321,7 +321,7 @@ def resolve_conflict(resolution: typing.Union[str, int] = 'IGNORE'):
 
 
 def run_script():
-    '''Run active script 
+    ''' Run active script
 
     '''
 
@@ -329,7 +329,7 @@ def run_script():
 
 
 def save():
-    '''Save active text data-block 
+    ''' Save active text data-block
 
     '''
 
@@ -357,49 +357,49 @@ def save_as(filepath: str = "",
             filemode: int = 9,
             display_type: typing.Union[str, int] = 'DEFAULT',
             sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
-    '''Save active text file with options 
+    ''' Save active text file with options
 
-    :param filepath: File Path, Path to file 
+    :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param check_existing: Check Existing, Check and warn on overwriting existing files 
+    :param check_existing: Check Existing, Check and warn on overwriting existing files
     :type check_existing: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
     '''
 
@@ -407,9 +407,9 @@ def save_as(filepath: str = "",
 
 
 def scroll(lines: int = 1):
-    '''Undocumented contribute <https://developer.blender.org/T51061> 
+    ''' Undocumented contribute <https://developer.blender.org/T51061>
 
-    :param lines: Lines, Number of lines to scroll 
+    :param lines: Lines, Number of lines to scroll
     :type lines: int
     '''
 
@@ -417,9 +417,9 @@ def scroll(lines: int = 1):
 
 
 def scroll_bar(lines: int = 1):
-    '''Undocumented contribute <https://developer.blender.org/T51061> 
+    ''' Undocumented contribute <https://developer.blender.org/T51061>
 
-    :param lines: Lines, Number of lines to scroll 
+    :param lines: Lines, Number of lines to scroll
     :type lines: int
     '''
 
@@ -427,7 +427,7 @@ def scroll_bar(lines: int = 1):
 
 
 def select_all():
-    '''Select all text 
+    ''' Select all text
 
     '''
 
@@ -435,7 +435,7 @@ def select_all():
 
 
 def select_line():
-    '''Select text by line 
+    ''' Select text by line
 
     '''
 
@@ -443,7 +443,7 @@ def select_line():
 
 
 def select_word():
-    '''Select word under cursor 
+    ''' Select word under cursor
 
     '''
 
@@ -451,7 +451,7 @@ def select_word():
 
 
 def selection_set():
-    '''Set cursor selection 
+    ''' Set cursor selection
 
     '''
 
@@ -459,7 +459,7 @@ def selection_set():
 
 
 def start_find():
-    '''Start searching text 
+    ''' Start searching text
 
     '''
 
@@ -467,9 +467,9 @@ def start_find():
 
 
 def to_3d_object(split_lines: bool = False):
-    '''Create 3D text object from active text data-block 
+    ''' Create 3D text object from active text data-block
 
-    :param split_lines: Split Lines, Create one object per line in the text 
+    :param split_lines: Split Lines, Create one object per line in the text
     :type split_lines: bool
     '''
 
@@ -477,7 +477,7 @@ def to_3d_object(split_lines: bool = False):
 
 
 def unindent():
-    '''Unindent selected text 
+    ''' Unindent selected text
 
     '''
 
@@ -485,7 +485,7 @@ def unindent():
 
 
 def unlink():
-    '''Unlink active text data-block 
+    ''' Unlink active text data-block
 
     '''
 
