@@ -336,13 +336,14 @@ def select_circle(x: int = 0,
     pass
 
 
-def select_lasso(path: typing.Union[typing.List['bpy.types.OperatorMousePath'],
-                                    'bpy_prop_collection'] = None,
+def select_lasso(path: typing.Union[
+        typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.
+        List['bpy.types.OperatorMousePath'], 'bpy_prop_collection'] = None,
                  mode: typing.Union[str, int] = 'SET'):
     ''' Select UVs using lasso selection
 
     :param path: Path
-    :type path: typing.Union[typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
+    :type path: typing.Union[typing.Dict[str, 'bpy.types.OperatorMousePath'], typing.List['bpy.types.OperatorMousePath'], 'bpy_prop_collection']
     :param mode: Mode * SET Set, Set a new selection. * ADD Extend, Extend existing selection. * SUB Subtract, Subtract existing selection.
     :type mode: typing.Union[str, int]
     '''
@@ -493,18 +494,20 @@ def sphere_project(direction: typing.Union[str, int] = 'VIEW_ON_EQUATOR',
     pass
 
 
-def stitch(use_limit: bool = False,
-           snap_islands: bool = True,
-           limit: float = 0.01,
-           static_island: int = 0,
-           active_object_index: int = 0,
-           midpoint_snap: bool = False,
-           clear_seams: bool = True,
-           mode: typing.Union[str, int] = 'VERTEX',
-           stored_mode: typing.Union[str, int] = 'VERTEX',
-           selection: typing.Union[typing.List['bpy.types.SelectedUvElement'],
-                                   'bpy_prop_collection'] = None,
-           objects_selection_count: typing.List[int] = (0, 0, 0, 0, 0, 0)):
+def stitch(
+        use_limit: bool = False,
+        snap_islands: bool = True,
+        limit: float = 0.01,
+        static_island: int = 0,
+        active_object_index: int = 0,
+        midpoint_snap: bool = False,
+        clear_seams: bool = True,
+        mode: typing.Union[str, int] = 'VERTEX',
+        stored_mode: typing.Union[str, int] = 'VERTEX',
+        selection: typing.Union[
+            typing.Dict[str, 'bpy.types.SelectedUvElement'], typing.
+            List['bpy.types.SelectedUvElement'], 'bpy_prop_collection'] = None,
+        objects_selection_count: typing.List[int] = (0, 0, 0, 0, 0, 0)):
     ''' Stitch selected UV vertices by proximity
 
     :param use_limit: Use Limit, Stitch UVs within a specified limit distance
@@ -526,7 +529,7 @@ def stitch(use_limit: bool = False,
     :param stored_mode: Stored Operation Mode, Use vertex or edge stitching
     :type stored_mode: typing.Union[str, int]
     :param selection: Selection
-    :type selection: typing.Union[typing.List['bpy.types.SelectedUvElement'], 'bpy_prop_collection']
+    :type selection: typing.Union[typing.Dict[str, 'bpy.types.SelectedUvElement'], typing.List['bpy.types.SelectedUvElement'], 'bpy_prop_collection']
     :param objects_selection_count: Objects Selection Count
     :type objects_selection_count: typing.List[int]
     '''
