@@ -242,36 +242,37 @@ def alembic_import(filepath: str = "",
     pass
 
 
-def append(
-        filepath: str = "",
-        directory: str = "",
-        filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
-        filter_blender: bool = True,
-        filter_backup: bool = False,
-        filter_image: bool = False,
-        filter_movie: bool = False,
-        filter_python: bool = False,
-        filter_font: bool = False,
-        filter_sound: bool = False,
-        filter_text: bool = False,
-        filter_archive: bool = False,
-        filter_btx: bool = False,
-        filter_collada: bool = False,
-        filter_alembic: bool = False,
-        filter_usd: bool = False,
-        filter_folder: bool = True,
-        filter_blenlib: bool = True,
-        filemode: int = 1,
-        display_type: typing.Union[str, int] = 'DEFAULT',
-        sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
-        link: bool = False,
-        autoselect: bool = True,
-        active_collection: bool = True,
-        instance_collections: bool = False,
-        set_fake: bool = False,
-        use_recursive: bool = True):
+def append(filepath: str = "",
+           directory: str = "",
+           filename: str = "",
+           files: typing.
+           Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+                 List['bpy.types.OperatorFileListElement'],
+                 'bpy_prop_collection'] = None,
+           filter_blender: bool = True,
+           filter_backup: bool = False,
+           filter_image: bool = False,
+           filter_movie: bool = False,
+           filter_python: bool = False,
+           filter_font: bool = False,
+           filter_sound: bool = False,
+           filter_text: bool = False,
+           filter_archive: bool = False,
+           filter_btx: bool = False,
+           filter_collada: bool = False,
+           filter_alembic: bool = False,
+           filter_usd: bool = False,
+           filter_folder: bool = True,
+           filter_blenlib: bool = True,
+           filemode: int = 1,
+           display_type: typing.Union[str, int] = 'DEFAULT',
+           sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
+           link: bool = False,
+           autoselect: bool = True,
+           active_collection: bool = True,
+           instance_collections: bool = False,
+           set_fake: bool = False,
+           use_recursive: bool = True):
     ''' Append from a Library .blend file
 
     :param filepath: File Path, Path to file
@@ -281,7 +282,7 @@ def append(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -338,8 +339,10 @@ def append(
 def batch_rename(
         data_type: typing.Union[str, int] = 'OBJECT',
         data_source: typing.Union[str, int] = 'SELECT',
-        actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'],
-                              'bpy_prop_collection'] = None):
+        actions: typing.
+        Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.
+              List['bl_operators.wm.BatchRenameAction'],
+              'bpy_prop_collection'] = None):
     ''' Undocumented contribute <https://developer.blender.org/T51061>
 
     :param data_type: Type, Type of data to rename
@@ -347,7 +350,7 @@ def batch_rename(
     :param data_source: Source
     :type data_source: typing.Union[str, int]
     :param actions: actions
-    :type actions: typing.Union[typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
+    :type actions: typing.Union[typing.Dict[str, 'bl_operators.wm.BatchRenameAction'], typing.List['bl_operators.wm.BatchRenameAction'], 'bpy_prop_collection']
     '''
 
     pass
@@ -1064,8 +1067,10 @@ def lib_relocate(
         filepath: str = "",
         directory: str = "",
         filename: str = "",
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         hide_props_region: bool = True,
         filter_blender: bool = True,
         filter_backup: bool = False,
@@ -1097,7 +1102,7 @@ def lib_relocate(
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
     :param filter_blender: Filter .blend files
@@ -1146,8 +1151,10 @@ def lib_relocate(
 def link(filepath: str = "",
          directory: str = "",
          filename: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          filter_blender: bool = True,
          filter_backup: bool = False,
          filter_image: bool = False,
@@ -1180,7 +1187,7 @@ def link(filepath: str = "",
     :param filename: File Name, Name of the file
     :type filename: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -1397,8 +1404,10 @@ def path_open(filepath: str = ""):
 
 
 def previews_batch_clear(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1411,7 +1420,7 @@ def previews_batch_clear(
     ''' Clear selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
@@ -1436,8 +1445,10 @@ def previews_batch_clear(
 
 
 def previews_batch_generate(
-        files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                            'bpy_prop_collection'] = None,
+        files: typing.
+        Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+              List['bpy.types.OperatorFileListElement'],
+              'bpy_prop_collection'] = None,
         directory: str = "",
         filter_blender: bool = True,
         filter_folder: bool = True,
@@ -1450,7 +1461,7 @@ def previews_batch_generate(
     ''' Generate selected .blend file's previews
 
     :param files: files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param directory: directory
     :type directory: str
     :param filter_blender: filter_blender
