@@ -1,10 +1,10 @@
 import sys
 import typing
-from . import geometry
-from . import kdtree
-from . import interpolate
 from . import noise
+from . import kdtree
 from . import bvhtree
+from . import interpolate
+from . import geometry
 
 
 class Color:
@@ -156,11 +156,11 @@ class Euler:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
         ''' Rotates the euler by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
         '''
         pass
 
@@ -473,11 +473,11 @@ class Matrix:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
         ''' Rotates the matrix by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
         '''
         pass
 
@@ -727,11 +727,11 @@ class Quaternion:
         '''
         pass
 
-    def rotate(self, other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(self, other: typing.Union['Quaternion', 'Euler', 'Matrix']):
         ''' Rotates the quaternion by another mathutils value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
         '''
         pass
 
@@ -2086,11 +2086,11 @@ class Vector:
         pass
 
     @staticmethod
-    def rotate(other: typing.Union['Euler', 'Matrix', 'Quaternion']):
+    def rotate(other: typing.Union['Quaternion', 'Euler', 'Matrix']):
         ''' Rotate the vector by a rotation value.
 
         :param other: rotation component of mathutils value
-        :type other: typing.Union['Euler', 'Matrix', 'Quaternion']
+        :type other: typing.Union['Quaternion', 'Euler', 'Matrix']
         '''
         pass
 
